#!/usr/bin/env python3
# -*- coding: utf-8 -*-

# Package database

generic_audio_icon = "audio-x-generic"
generic_midi_icon  = "audio-midi"

LEVEL_0    = "Ni. 0"
LEVEL_1    = "Ni. 1"
LEVEL_LASH = "LASH"
LEVEL_JS   = "JACK-Session"
LEVEL_NSM  = "NSM"

TEMPLATE_YES = "Oui"
TEMPLATE_NO  = "Non"

USING_KXSTUDIO = False

# -------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
# DAW

# (L, D, L, V, VST-Mode, T, M, MIDI-Mode) -> (LADSPA, DSSI, LV2, VST, VST-Mode, Transport, MIDI, MIDI-Mode)

list_DAW = [
  # Package          AppName            Type              Binary              Icon                Template?     Level      (L, D, L, V, VST-Mode,  T, M, MIDI-Mode)      (doc-file,                                                         website)
  [ "ardour",        "Ardour 6",        "STAN",     "ardour",  "/usr/share/pixmaps/ardour.svg",   TEMPLATE_NO,  LEVEL_NSM, (1, 0, 1, 0, "Native",  1, 1, "JACK"),        ("", "https://librazik.tuxfamily.org/doc3/logiciels/ardour") ],

  [ "ariamaestosa",  "Aria Maestosa",   "Séquenceur MIDI", "Aria",  "/usr/share/Aria/aria64.png", TEMPLATE_NO,  LEVEL_0,   (0, 0, 0, 0, "",        0, 1, "ALSA | JACK"), ("", "https://librazik.tuxfamily.org/doc3/logiciels/ariamaestosa") ],

  [ "giada",         "Giada",           "Boucleur audio", "giada",            "giada",            TEMPLATE_NO,  LEVEL_0,   (0, 0, 0, 0, "",        0, 0, ""),            ("", "https://librazik.tuxfamily.org/doc3/logiciels/giada") ],

  [ "hydrogen",      "Hydrogen",        "Boîte à rythmes","hydrogen -d jack", "/usr/share/icons/hicolor/scalable/apps/org.hydrogenmusic.Hydrogen.svg",          TEMPLATE_YES, LEVEL_NSM, (1, 0, 0, 0, "",        1, 1, "ALSA | JACK"), ("", "https://librazik.tuxfamily.org/doc3/logiciels/hydrogen") ],

  [ "jacker",        "Jacker",          "Tracker MIDI",   "jacker",           "jacker",           TEMPLATE_YES, LEVEL_0,   (0, 0, 0, 0, "",        1, 1, "JACK"),        ("",                                                               "") ],

  [ "klystrack",     "Klystrack",       "Tracker Chiptune", "klystrack",      "klystrack",        TEMPLATE_NO,  LEVEL_0,   (0, 0, 0, 0, "",       0, 0, "----"),        ("", "https://librazik.tuxfamily.org/doc3/logiciels/klystrack") ],

  [ "lmms",          "LMMS",            "STAN",           "lmms",             "lmms",             TEMPLATE_YES, LEVEL_0,   (1, 0, 0, 1, "Windows", 0, 1, "ALSA"),        ("", "https://librazik.tuxfamily.org/doc3/logiciels/lmms") ],

  [ "milkytracker",  "MilkyTracker",    "Tracker",        "milkytracker",     "milkytracker",     TEMPLATE_NO,  LEVEL_0,   (0, 0, 0, 0, "",        0, 1, "ALSA"),        ("", "https://librazik.tuxfamily.org/doc3/logiciels/milkytracker") ],

  [ "muse",          "MusE",            "STAN",           "muse",             "muse_icon",        TEMPLATE_YES, LEVEL_0,   (1, 1, 0, 1, "Native",  1, 1, "ALSA + JACK"), ("", "https://librazik.tuxfamily.org/doc3/logiciels/muse") ],

  [ "musescore3",    "MuseScore 3",     "Compositeur MIDI", "mscore3",        "mscore3",          TEMPLATE_NO,  LEVEL_0,   (0, 0, 0, 0, "",        1, 1, "ALSA | JACK"), ("", "https://librazik.tuxfamily.org/doc3/logiciels/musescore") ],

  [ "non-sequencer", "Non-Sequencer",  "Séquenceur MIDI", "non-sequencer",    "non-sequencer",    TEMPLATE_YES, LEVEL_NSM, (0, 0, 0, 0, "",        1, 1, "JACK"),        ("", "https://librazik.tuxfamily.org/doc3/logiciels/non-suite/non-sequencer") ],
  [ "non-timeline",  "Non-Timeline",    "STAN",           "non-timeline",     "non-timeline",     TEMPLATE_YES, LEVEL_NSM, (0, 0, 0, 0, "",        1, 0, "CV + OSC"),    ("", "https://librazik.tuxfamily.org/doc3/logiciels/non-suite/non-timeline") ],

  [ "protrekkr",     "ProTrekkr",       "Tracker",        "protrekkr",        "protrekkr",        TEMPLATE_NO,  LEVEL_0,   (0, 0, 0, 1, "",        0, 1, "ALSA"),        ("",                                                               "") ],

  [ "qtractor",      "Qtractor",        "STAN",           "qtractor",         "qtractor",         TEMPLATE_YES, LEVEL_1,   (1, 1, 1, 1, "Native",  1, 1, "ALSA"),        ("", "https://librazik.tuxfamily.org/doc3/logiciels/qtractor") ],

  [ "rosegarden",    "Rosegarden",     "Séquenceur MIDI", "rosegarden",       "rosegarden",       TEMPLATE_YES, LEVEL_1,   (1, 1, 0, 0, "",        1, 1, "ALSA"),        ("", "https://librazik.tuxfamily.org/doc3/logiciels/rosegarden") ],

  [ "schism",      "Schism",  "Clone d'Impulse Tracker",  "schismtracker",    "schism-icon-128",  TEMPLATE_YES, LEVEL_0,   (0, 0, 0, 0, "",        0, 1, "ALSA"),        ("", "https://librazik.tuxfamily.org/doc3/logiciels/schism") ],

  [ "seq24",         "Seq24",          "Séquenceur MIDI", "seq24",            "seq24",            TEMPLATE_YES, LEVEL_1,   (0, 0, 0, 0, "",        1, 1, "ALSA"),        ("", "https://librazik.tuxfamily.org/doc3/logiciels/seq24") ],

  [ "sooperlooper",  "SooperLooper",  "Boucleur audio",   "slgui",            "sooperlooper",     TEMPLATE_NO,  LEVEL_0,   (0, 0, 0, 0, "",       0, 1, "JACK"),        ("", "https://librazik.tuxfamily.org/doc3/logiciels/sooperlooper") ],

  [ "tutka",         "Tutka",           "Tracker MIDI",   "tutka",            "tutka",            TEMPLATE_NO,  LEVEL_0,   (0, 0, 0, 0, "",       0, 1, "JACK"),        ("", "https://librazik.tuxfamily.org/doc3/logiciels/tutka") ],
]

iDAW_Package, iDAW_AppName, iDAW_Type, iDAW_Binary, iDAW_Icon, iDAW_Template, iDAW_Level, iDAW_Features, iDAW_Docs = range(0, len(list_DAW[0]))

if USING_KXSTUDIO:
    # Jacker
    list_DAW[4][iDAW_Level] = LEVEL_1

# -------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
# Host

# (I, L, D, L, V, VST-Mode, MIDI-Mode) -> (Internal, LADSPA, DSSI, LV2, VST, VST-Mode, MIDI-Mode)

list_Host = [
  # Package               AppName                 Ins?   FX?    Binary                Icon                Template?     Level      (I, L, D, L, V, VST-Mode,  MIDI-Mode)      (doc-file,                                website)
  [ "ams",                "AlsaModularSynth",     "Oui", "Oui", "ams",                "ams_32",           TEMPLATE_NO,  LEVEL_0,   (1, 1, 0, 0, 0, "",        "ALSA"),        ("",                                      "") ],

  [ "calf-plugins",       "Calf Jack Host",       "Oui", "Oui", "calfjackhost",       "calf",             TEMPLATE_YES, LEVEL_1,   (1, 0, 0, 0, 0, "",        "JACK"),        ("", "https://librazik.tuxfamily.org/doc3/logiciels/calf-plugins") ],
  [ "calf-plugins-git",   "Calf Jack Host (GIT)", "Oui", "Oui", "calfjackhost",       "calf",             TEMPLATE_YES, LEVEL_1,   (1, 0, 0, 0, 0, "",        "JACK"),        ("", "https://librazik.tuxfamily.org/doc3/logiciels/calf-plugins") ],

  [ "carla",              "Carla",                "Oui", "Oui", "carla",              "carla",            TEMPLATE_YES, LEVEL_1,   (1, 1, 1, 1, 1, "Both",    "ALSA | JACK"), ("", "https://librazik.tuxfamily.org/doc3/logiciels/carla-ensemble/carla") ],
  [ "carla-git",          "Carla (GIT)",          "Oui", "Oui", "carla",              "carla",            TEMPLATE_YES, LEVEL_NSM, (1, 1, 1, 1, 1, "Both",    "ALSA | JACK"), ("", "https://librazik.tuxfamily.org/doc3/logiciels/carla-ensemble/carla") ],

  [ "festige",            "FeSTige",              "Oui", "Oui", "festige",            "festige",          TEMPLATE_NO,  LEVEL_1,   (0, 0, 0, 0, 1, "Windows", "ALSA | JACK"), ("",                                      "") ],

  [ "ingen",              "Ingen",                "Oui", "Oui", "ingen -eg",          "ingen",            TEMPLATE_NO,  LEVEL_0,   (1, 0, 0, 1, 0, "",        "JACK"),        ("",                                      "") ],

  [ "jack-rack",        "Jack Rack",      "Non",  "Oui", "jack-rack",     "/usr/share/pixmaps/jack-rack-icon.png",   TEMPLATE_YES, LEVEL_0,   (0, 1, 0, 0, 0, "",        "ALSA"),        ("", "https://librazik.tuxfamily.org/doc3/logiciels/jack-rack") ],

  [ "jalv.select",      "Jalv.select",    "Non",  "Non", "jalv.select",   "/usr/share/pixmaps/lv2.png",              TEMPLATE_YES, LEVEL_0,   (0, 0, 0, 1, 0, "",        "---"),         ("", "https://librazik.tuxfamily.org/doc3/logiciels/jalv.select") ],

  [ "mod-app",            "MOD App",              "Oui", "Oui", "mod-app",            "mod",              TEMPLATE_NO,  LEVEL_0,   (0, 0, 0, 1, 0, "",        "JACK"),        ("",                                      "") ],

  [ "spiralsynthmodular", "SpiralSynthModular",   "Oui", "Oui", "spiralsynthmodular", generic_audio_icon, TEMPLATE_NO,  LEVEL_0,   (1, 0, 0, 0, 0, "",        "ALSA"),        ("",                                      "") ],
]

iHost_Package, iHost_AppName, iHost_Ins, iHost_FX, iHost_Binary, iHost_Icon, iHost_Template, iHost_Level, iHost_Features, iDAW_Docs = range(0, len(list_Host[0]))

# -------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
# Instrument

# (F, I, MIDI-Mode) -> (Built-in FX, Audio Input, MIDI-Mode)

list_Instrument = [
  # Package                 AppName              Type                Binary                    Icon                Template?     Level      (F, I, MIDI-Mode)      (doc-file,                                                            website)
  [ "6pm",                  "6 PM",              "Synthétiseur",     "6pm",                    "6PM-icon",         TEMPLATE_NO,  LEVEL_0,   (0, 0, "JACK"),        ("", "https://librazik.tuxfamily.org/doc3/logiciels/6pm") ],

  [ "add64",                "Add64",             "Synthétiseur",     "Add64",                  "add64",            TEMPLATE_NO,  LEVEL_0,   (1, 0, "JACK"),        ("", "https://librazik.tuxfamily.org/doc3/logiciels/add64") ],

  [ "aeolus",               "Aeolus",            "Organ Emulator",   "aeolus -J",              "audio-x-generic",  TEMPLATE_NO,  LEVEL_0,   (0, 0,       "JACK"),        ("", "https://librazik.tuxfamily.org/doc3/logiciels/aeolus") ],

  [ "amsynth",              "AmSynth",           "Synthétiseur",     "amsynth",                "amsynth",          TEMPLATE_NO,  LEVEL_0,   (0, 0,   "ALSA | JACK"), ("", "https://librazik.tuxfamily.org/doc3/logiciels/amsynth") ],

  [ "azr3-jack",            "AZR3",              "Synthétiseur",     "azr3",                   "/usr/share/pixmaps/azr3-jack.xpm",        TEMPLATE_NO,  LEVEL_0,   (1, 0, "JACK"),        ("", "https://librazik.tuxfamily.org/doc3/logiciels/azr3-jack") ],

  [ "borderlands",          "Borderlands",       "Échantillonneur",  "Borderlands",            "borderlands",      TEMPLATE_NO,  LEVEL_0,   (0, 1, "JACK"),        ("", "https://librazik.tuxfamily.org/doc3/logiciels/borderlands") ],

  [ "coldgaze",             "Coldgaze",          "Synthétiseur",     "microSynth",             "coldgaze",         TEMPLATE_NO,  LEVEL_0,   (0, 0, "ALSA"),        ("", "https://librazik.tuxfamily.org/doc3/logiciels/coldgaze") ],

  [ "cursynth",             "cursynth",    "Synthétiseur",  "x-terminal-emulator -e cursynth", generic_audio_icon, TEMPLATE_NO,  LEVEL_0,   (0, 0, "ALSA"),        ("",                                                                  "") ],

  [ "distrho-lv2",          "Dexed",         "Émulateur de Yamaha DX7",  "Dexed",              "dexed",            TEMPLATE_NO,  LEVEL_0,   (0, 0, "JACK"),        ("", "https://librazik.tuxfamily.org/doc3/logiciels/distrho-lv2/dexed") ],

  [ "din",                  "DIN",               "Instrument musical",   "din",                "din",              TEMPLATE_NO,  LEVEL_0,   (0, 0, "JACK"),        ("", "https://librazik.tuxfamily.org/doc3/logiciels/din") ],

  [ "drumkv1",     "Drumk-V1",    "Échantillonneur de batterie",     "drumkv1_jack",           "drumkv1",          TEMPLATE_NO,  LEVEL_JS,  (0, 0, "ALSA | JACK"),       ("", "https://librazik.tuxfamily.org/doc3/logiciels/drumkv1") ],

  [ "distrho-lv2",          "DrumSynth", "Synthétiseur de batterie", "DrumSynth",              "drumsynth",        TEMPLATE_NO,  LEVEL_0,   (0, 0, "JACK"),        ("", "https://librazik.tuxfamily.org/doc3/logiciels/distrho-lv2/drumsynth") ],

  [ "fabla",          "Fabla",    "Échantillonneur de batterie",     "fabla",                  "fabla",            TEMPLATE_NO,  LEVEL_0,   (0, 0, "JACK"),        ("", "https://librazik.tuxfamily.org/doc3/logiciels/fabla") ],

  [ "fabla2",               "Fabla 2",           "Échantillonneur",  "fabla2",                 "fabla2",           TEMPLATE_NO,  LEVEL_0,   (0, 1, "JACK"),        ("", "https://librazik.tuxfamily.org/doc3/logiciels/fabla2") ],

  [ "foo-yc20",       "Foo YC20",   "Synthétiseur d'orgue",   "foo-yc20", "/usr/share/foo-yc20/graphics/icon.png", TEMPLATE_NO,  LEVEL_0,   (0, 0, "JACK"),        ("", "https://librazik.tuxfamily.org/doc3/logiciels/foo-yc20") ],

  [ "grandorgue", "GrandOrgue", "Échantillonneur de grand orgue", "GrandOrgue", "/usr/share/pixmaps/GrandOrgue.png", TEMPLATE_NO,  LEVEL_0,   (0, 0, "JACK"),        ("", "https://librazik.tuxfamily.org/doc3/logiciels/grandorgue") ],

  [ "helm",                 "Helm",              "Synthétiseur",     "helm",                   "helm_icon_128_1x", TEMPLATE_NO,  LEVEL_0,   (1, 1, "JACK"),        ("", "https://librazik.tuxfamily.org/doc3/logiciels/helm") ],

  [ "hexter",               "Hexter",            "Synthétiseur",  "jack-dssi-host hexter.so",  "hexter",           TEMPLATE_NO,  LEVEL_0,   (0, 0, "ALSA"),        ("", "https://librazik.tuxfamily.org/doc3/logiciels/hexter") ],

  [ "horgand",              "Horgand",           "Synthétiseur",     "horgand",                "horgand128",       TEMPLATE_NO,  LEVEL_0,   (0, 0, "JACK"),        ("", "https://librazik.tuxfamily.org/doc3/logiciels/horgand") ],

  [ "infamous-plugins", "Infamous Cellular Automaton Synth", "Synthétiseur", "infamous-casynth", "infamous-casynth",  TEMPLATE_NO,  LEVEL_0,   (0, 1, "JACK"), ("", "https://librazik.tuxfamily.org/doc3/logiciels/infamous-plugins/the_infamous_cellular_automaton_synth") ],

  [ "jsampler",             "JSampler Fantasia", "Échantillonneur",  "jsampler-bin",           "jsampler",         TEMPLATE_NO,  LEVEL_0,   (0, 0, "ALSA + JACK"),       ("file:///usr/share/kxstudio/docs/jsampler/jsampler.html") ],

  [ "distrho-lv2",          "Juce Demo Plugin",  "Synthétiseur",     "JuceDemoPlugin",         "jucedemoplugin",   TEMPLATE_NO,  LEVEL_0,   (0, 0, "JACK"),        ("", "https://librazik.tuxfamily.org/doc3/logiciels/distrho-lv2/jucedemoplugin") ],

  [ "dpf-plugins",          "Kars",            "Instrument virtuel", "Kars",                   "kars",             TEMPLATE_NO,  LEVEL_0,   (0, 0, "JACK"),        ("", "https://librazik.tuxfamily.org/doc3/logiciels/dpf-plugins/kars") ],

  [ "dpf-plugins",          "Nekobi",  "Émulateur de Roland TB-303", "Nekobi",                 "nekobi",           TEMPLATE_NO,  LEVEL_0,   (0, 0, "JACK"),        ("", "https://librazik.tuxfamily.org/doc3/logiciels/dpf-plugins/nekobi") ],

  [ "distrho-lv2",          "TAL Noize Mak3r",   "Synthétiseur",     "NoizeMak3r",             "noizemak3r",       TEMPLATE_NO,  LEVEL_0,   (1, 0, "JACK"),        ("", "https://librazik.tuxfamily.org/doc3/logiciels/distrho-lv2/noize_mak3r") ],

  [ "distrho-lv2",        "Obxd",  "Émulateurs de ob-x, ob-xa & ob8", "Obxd",                   "obxd",            TEMPLATE_NO,  LEVEL_0,   (0, 0, "JACK"),        ("", "https://librazik.tuxfamily.org/doc3/logiciels/distrho-lv2/obxd") ],

  [ "padthv1",              "Padth-V1",          "Synthétiseur",     "padthv1_jack",           "padthv1",          TEMPLATE_NO,  LEVEL_NSM, (0, 0, "ALSA | JACK"),       ("", "https://librazik.tuxfamily.org/doc3/logiciels/padthv1") ],

  [ "petri-foo",            "Petri-Foo",         "Échantillonneur",  "petri-foo",              "petri-foo",        TEMPLATE_NO,  LEVEL_NSM, (0, 0, "ALSA + JACK"),       ("", "https://librazik.tuxfamily.org/doc3/logiciels/petri-foo") ],

  [ "phasex",               "Phasex",            "Synthétiseur",     "phasex",                 "phasex",           TEMPLATE_NO,  LEVEL_0,   (1, 1, "ALSA"),        ("", "https://librazik.tuxfamily.org/doc3/logiciels/phasex") ],

  [ "polyphone",            "Polyphone",         "Échantillonneur",  "polyphone",              "polyphone",        TEMPLATE_NO,  LEVEL_0,   (1, 0, "JACK"),        ("", "https://librazik.tuxfamily.org/doc3/logiciels/polyphone") ],

  [ "qsampler",             "Qsampler",          "Échantillonneur",  "qsampler",               "qsampler",         TEMPLATE_YES, LEVEL_0,   (0, 0, "ALSA + JACK"),       ("", "https://librazik.tuxfamily.org/doc3/logiciels/qsampler") ],

  [ "qsynth",               "Qsynth",   "Lecteur de banque de sons", "qsynth -a jack -m jack", "qsynth",           TEMPLATE_NO,  LEVEL_0,   (1, 0, "ALSA | JACK"),       ("", "https://librazik.tuxfamily.org/doc3/logiciels/qsynth") ],

  [ "samplv1",              "Sampl-V1",          "Échantillonneur",  "samplv1_jack",           "samplv1",          TEMPLATE_NO,  LEVEL_NSM, (0, 0, "ALSA | JACK"),       ("", "https://librazik.tuxfamily.org/doc3/logiciels/samplv1") ],

  [ "setbfree",             "SetBfree",       "Émulateur d'orgue",   "setBfreeUI",             "setBfree",         TEMPLATE_NO,  LEVEL_0,   (0, 0, "JACK"),        ("", "https://librazik.tuxfamily.org/doc3/logiciels/setbfree/setbfree") ],

  [ "sorcer",               "Sorcer",   "Synthétiseur polyphonique", "sorcer",                 "sorcer",           TEMPLATE_NO,  LEVEL_NSM, (0, 0, "JACK"),        ("", "https://librazik.tuxfamily.org/doc3/logiciels/sorcer") ],

  [ "spectmorph",           "Spectmorph",  "Synthétiseur par morphose sonore",   "smjack",     "smjack",           TEMPLATE_NO,  LEVEL_0,   (0, 0, "JACK"),        ("", "https://librazik.tuxfamily.org/doc3/logiciels/spectmorph") ],

  [ "stegosaurus",   "Stegosaurus",  "Synthétiseur de batterie analogique",  "stegosaurus",    "stegosaurus",      TEMPLATE_NO,  LEVEL_0,   (0, 0, "JACK"),        ("", "https://librazik.tuxfamily.org/doc3/logiciels/stegosaurus") ],

  [ "synthv1",              "Synth-V1",          "Synthétiseur",     "synthv1_jack",           "synthv1",          TEMPLATE_NO,  LEVEL_NSM, (0, 0, "ALSA | JACK"),       ("", "https://librazik.tuxfamily.org/doc3/logiciels/synthv1") ],

  [ "tapeutape",            "Tapeutape",         "Échantillonneur",  "tapeutape",              "tapeutape",        TEMPLATE_NO,  LEVEL_0,   (0, 1, "ALSA"),        ("", "https://librazik.tuxfamily.org/doc3/logiciels/tapeutape") ],

  [ "triceratops-lv2",      "Triceratops",       "Synthétiseur polyphonique",  "triceratops",  "triceratops",      TEMPLATE_NO,  LEVEL_0,   (0, 0, "JACK"),        ("", "https://librazik.tuxfamily.org/doc3/logiciels/triceratops") ],

  [ "vcvrack",              "VCV Rack",          "Synthétiseur modulaire",    "vcvrack",       "vcvrack",          TEMPLATE_NO,  LEVEL_0,   (0, 0, "---"),         ("", "https://librazik.tuxfamily.org/doc3/logiciels/vcvrack") ],

  [ "distrho-lv2",          "Vex",               "Synthétiseur",     "Vex",                    "vex",              TEMPLATE_NO,  LEVEL_0,   (0, 0, "JACK"),        ("", "https://librazik.tuxfamily.org/doc3/logiciels/distrho-lv2/vex") ],

  [ "whysynth",             "Whysynth",          "Synthétiseur",     "whysynth",               "whysynth",         TEMPLATE_NO,  LEVEL_0,   (1, 0, "JACK"),        ("", "https://librazik.tuxfamily.org/doc3/logiciels/whysynth") ],

  [ "distrho-lv2",      "Wolpertinger",  "Synthétiseur",  "Wolpertinger",  "/usr/share/pixmaps/wolpertinger.xpm",  TEMPLATE_NO,  LEVEL_0,   (0, 0, "JACK"),        ("", "https://librazik.tuxfamily.org/doc3/logiciels/distrho-lv2/wolpertinger") ],

  [ "wsynth-dssi",  "Wsynth",  "Synthétiseur par table d'onde",  "jack-dssi-host wsynth-dssi.so",  "wsynth-dssi",  TEMPLATE_NO,  LEVEL_0,   (1, 0, "JACK"),        ("", "https://librazik.tuxfamily.org/doc3/logiciels/wsynth-dssi") ],

  [ "xsynth-dssi",          "Xsynth",            "Synthétiseur analogique",     "jack-dssi-host xsynth-dssi.so", "xsynth-dssi", TEMPLATE_NO,  LEVEL_0,   (1, 0, "JACK"),        ("", "https://librazik.tuxfamily.org/doc3/logiciels/xsynth-dssi") ],

  [ "yoshimi",              "Yoshimi",           "Synthétiseur",     "yoshimi -j -J",  "/usr/share/pixmaps/yoshimi.png",          TEMPLATE_NO,  LEVEL_1,   (1, 0, "ALSA | JACK"),       ("", "https://librazik.tuxfamily.org/doc3/logiciels/yoshimi") ],

  [ "zynaddsubfx",          "ZynAddSubFX",       "Synthétiseur",     "zynaddsubfx",            "zynaddsubfx",      TEMPLATE_NO,  LEVEL_NSM, (1, 0, "ALSA | JACK"),       ("", "https://librazik.tuxfamily.org/doc3/logiciels/zynaddsubfx") ],
  [ "zynaddsubfx-git",      "ZynAddSubFX (GIT)", "Synthétiseur",     "zynaddsubfx",            "zynaddsubfx",      TEMPLATE_NO,  LEVEL_NSM, (1, 0, "ALSA | JACK"),       ("", "https://librazik.tuxfamily.org/doc3/logiciels/zynaddsubfx") ],
]

iInstrument_Package, iInstrument_AppName, iInstrument_Type, iInstrument_Binary, iInstrument_Icon, iInstrument_Template, iInstrument_Level, iInstrument_Features, iInstrument_Docs = range(0, len(list_Instrument[0]))

# -------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
# Bristol

# Need name: bit99, bit100

list_Bristol = [
  # Package    AppName                           Type            Short-name    Icon                  Template?     Level    (F, I, MIDI-Mode)      (doc-file, website)
  [ "bristol", "Moog Voyager",                   "Synthétiseur", "explorer",   "bristol_explorer",   TEMPLATE_NO,  LEVEL_1, (1, 1, "ALSA | JACK"), ("", "https://librazik.tuxfamily.org/doc3/logiciels/monobristol") ],
  [ "bristol", "Moog Mini",                      "Synthétiseur", "mini",       "bristol_mini",       TEMPLATE_NO,  LEVEL_1, (1, 1, "ALSA | JACK"), ("", "https://librazik.tuxfamily.org/doc3/logiciels/monobristol") ],
  [ "bristol", "Sequential Circuits Prophet-52", "Synthétiseur", "prophet52",  "bristol_prophet52",  TEMPLATE_NO,  LEVEL_1, (1, 1, "ALSA | JACK"), ("", "https://librazik.tuxfamily.org/doc3/logiciels/monobristol") ],

  [ "bristol", "Moog/Realistic MG-1",            "Synthétiseur", "realistic",  "bristol_realistic",  TEMPLATE_NO,  LEVEL_1, (1, 1, "ALSA | JACK"), ("", "https://librazik.tuxfamily.org/doc3/logiciels/monobristol") ],
  [ "bristol", "Memory Moog",                    "Synthétiseur", "memoryMoog", "bristol_memoryMoog", TEMPLATE_NO,  LEVEL_1, (1, 1, "ALSA | JACK"), ("", "https://librazik.tuxfamily.org/doc3/logiciels/monobristol") ],
  [ "bristol", "Baumann BME-700",                "Synthétiseur", "BME700",     "bristol_BME700",     TEMPLATE_NO,  LEVEL_1, (1, 1, "ALSA | JACK"), ("", "https://librazik.tuxfamily.org/doc3/logiciels/monobristol") ],
 #[ "bristol", "Synthi Aks",                     "Synthétiseur", "aks",        "bristol_aks",        TEMPLATE_NO,  LEVEL_1, (1, 1, "ALSA | JACK"), ("", "http://bristol.sf.net/aks.html") ],
  [ "bristol", "Moog Voyager Blue Ice",          "Synthétiseur", "voyager",    "bristol_voyager",    TEMPLATE_NO,  LEVEL_1, (1, 1, "ALSA | JACK"), ("", "https://librazik.tuxfamily.org/doc3/logiciels/monobristol") ],
  [ "bristol", "Moog Sonic-6",                   "Synthétiseur", "sonic6",     "bristol_sonic6",     TEMPLATE_NO,  LEVEL_1, (1, 1, "ALSA | JACK"), ("", "https://librazik.tuxfamily.org/doc3/logiciels/monobristol") ],
  [ "bristol", "Hammond B3",                     "Synthétiseur", "hammondB3",  "bristol_hammondB3",  TEMPLATE_NO,  LEVEL_1, (1, 1, "ALSA | JACK"), ("", "https://librazik.tuxfamily.org/doc3/logiciels/monobristol") ],
  [ "bristol", "Sequential Circuits Prophet-5",  "Synthétiseur", "prophet",    "bristol_prophet",    TEMPLATE_NO,  LEVEL_1, (1, 1, "ALSA | JACK"), ("", "https://librazik.tuxfamily.org/doc3/logiciels/monobristol") ],
  [ "bristol", "Sequential Circuits Prophet-10", "Synthétiseur", "prophet10",  "bristol_prophet10",  TEMPLATE_NO,  LEVEL_1, (1, 1, "ALSA | JACK"), ("", "https://librazik.tuxfamily.org/doc3/logiciels/monobristol") ],
  [ "bristol", "Sequential Circuits Pro-1",      "Synthétiseur", "pro1",       "bristol_pro1",       TEMPLATE_NO,  LEVEL_1, (1, 1, "ALSA | JACK"), ("", "https://librazik.tuxfamily.org/doc3/logiciels/monobristol") ],
  [ "bristol", "Fender Rhodes Stage-73",         "Synthétiseur", "rhodes",     "bristol_rhodes",     TEMPLATE_NO,  LEVEL_1, (1, 1, "ALSA | JACK"), ("", "https://librazik.tuxfamily.org/doc3/logiciels/monobristol") ],
  [ "bristol", "Rhodes Bass Piano",              "Synthétiseur", "rhodesbass", "bristol_rhodesbass", TEMPLATE_NO,  LEVEL_1, (1, 1, "ALSA | JACK"), ("", "https://librazik.tuxfamily.org/doc3/logiciels/monobristol") ],
  [ "bristol", "Crumar Roadrunner",              "Synthétiseur", "roadrunner", "bristol_roadrunner", TEMPLATE_NO,  LEVEL_1, (1, 1, "ALSA | JACK"), ("", "https://librazik.tuxfamily.org/doc3/logiciels/monobristol") ],
  [ "bristol", "Crumar Bit-1",                   "Synthétiseur", "bitone",     "bristol_bitone",     TEMPLATE_NO,  LEVEL_1, (1, 1, "ALSA | JACK"), ("", "https://librazik.tuxfamily.org/doc3/logiciels/monobristol") ],
  [ "bristol", "Crumar Stratus",                 "Synthétiseur", "stratus",    "bristol_stratus",    TEMPLATE_NO,  LEVEL_1, (1, 1, "ALSA | JACK"), ("", "https://librazik.tuxfamily.org/doc3/logiciels/monobristol") ],
  [ "bristol", "Crumar Trilogy",                 "Synthétiseur", "trilogy",    "bristol_trilogy",    TEMPLATE_NO,  LEVEL_1, (1, 1, "ALSA | JACK"), ("", "https://librazik.tuxfamily.org/doc3/logiciels/monobristol") ],
  [ "bristol", "Oberheim OB-X",                  "Synthétiseur", "obx",        "bristol_obx",        TEMPLATE_NO,  LEVEL_1, (1, 1, "ALSA | JACK"), ("", "https://librazik.tuxfamily.org/doc3/logiciels/monobristol") ],
  [ "bristol", "Oberheim OB-Xa",                 "Synthétiseur", "obxa",       "bristol_obxa",       TEMPLATE_NO,  LEVEL_1, (1, 1, "ALSA | JACK"), ("", "https://librazik.tuxfamily.org/doc3/logiciels/monobristol") ],
  [ "bristol", "ARP Axxe",                       "Synthétiseur", "axxe",       "bristol_axxe",       TEMPLATE_NO,  LEVEL_1, (1, 1, "ALSA | JACK"), ("", "https://librazik.tuxfamily.org/doc3/logiciels/monobristol") ],
  [ "bristol", "ARP Odyssey",                    "Synthétiseur", "odyssey",    "bristol_odyssey",    TEMPLATE_NO,  LEVEL_1, (1, 1, "ALSA | JACK"), ("", "https://librazik.tuxfamily.org/doc3/logiciels/monobristol") ],
  [ "bristol", "ARP 2600",                       "Synthétiseur", "arp2600",    "bristol_arp2600",    TEMPLATE_NO,  LEVEL_1, (1, 1, "ALSA | JACK"), ("", "https://librazik.tuxfamily.org/doc3/logiciels/monobristol") ],
  [ "bristol", "ARP Solina Strings",             "Synthétiseur", "solina",     "bristol_solina",     TEMPLATE_NO,  LEVEL_1, (1, 1, "ALSA | JACK"), ("", "https://librazik.tuxfamily.org/doc3/logiciels/monobristol") ],
  [ "bristol", "Korg Poly-800",                  "Synthétiseur", "poly800",    "bristol_poly800",    TEMPLATE_NO,  LEVEL_1, (1, 1, "ALSA | JACK"), ("", "https://librazik.tuxfamily.org/doc3/logiciels/monobristol") ],
  [ "bristol", "Korg Mono/Poly",                 "Synthétiseur", "monopoly",   "bristol_monopoly",   TEMPLATE_NO,  LEVEL_1, (1, 1, "ALSA | JACK"), ("", "https://librazik.tuxfamily.org/doc3/logiciels/monobristol") ],
  [ "bristol", "Korg Polysix",                   "Synthétiseur", "poly",       "bristol_poly",       TEMPLATE_NO,  LEVEL_1, (1, 1, "ALSA | JACK"), ("", "https://librazik.tuxfamily.org/doc3/logiciels/monobristol") ],
  [ "bristol", "Korg MS-20 (*)",                 "Synthétiseur", "ms20",       "bristol_ms20",       TEMPLATE_NO,  LEVEL_1, (1, 1, "ALSA | JACK"), ("", "https://librazik.tuxfamily.org/doc3/logiciels/monobristol") ],
  [ "bristol", "VOX Continental",                "Synthétiseur", "vox",        "bristol_vox",        TEMPLATE_NO,  LEVEL_1, (1, 1, "ALSA | JACK"), ("", "https://librazik.tuxfamily.org/doc3/logiciels/monobristol") ],
  [ "bristol", "VOX Continental 300",            "Synthétiseur", "voxM2",      "bristol_voxM2",      TEMPLATE_NO,  LEVEL_1, (1, 1, "ALSA | JACK"), ("", "https://librazik.tuxfamily.org/doc3/logiciels/monobristol") ],
  [ "bristol", "Roland Juno-6",                  "Synthétiseur", "juno",       "bristol_juno",       TEMPLATE_NO,  LEVEL_1, (1, 1, "ALSA | JACK"), ("", "https://librazik.tuxfamily.org/doc3/logiciels/monobristol") ],
  [ "bristol", "Roland Jupiter 8",               "Synthétiseur", "jupiter8",   "bristol_jupiter8",   TEMPLATE_NO,  LEVEL_1, (1, 1, "ALSA | JACK"), ("", "https://librazik.tuxfamily.org/doc3/logiciels/monobristol") ],
 #[ "bristol", "Bristol BassMaker",              "Synthétiseur", "bassmaker",  "bristol_bassmaker",  TEMPLATE_NO,  LEVEL_1, (1, 1, "ALSA | JACK"), ("", "") ],
  [ "bristol", "Yamaha DX",                      "Synthétiseur", "dx",         "bristol_dx",         TEMPLATE_NO,  LEVEL_1, (1, 1, "ALSA | JACK"), ("", "https://librazik.tuxfamily.org/doc3/logiciels/monobristol") ],
 #[ "bristol", "Yamaha CS-80",                   "Synthétiseur", "cs80",       "bristol_cs80",       TEMPLATE_NO,  LEVEL_1, (1, 1, "ALSA | JACK"), ("", "http://bristol.sf.net/cs80.html") ],
  [ "bristol", "Bristol SID Softsynth",          "Synthétiseur", "sidney",     "bristol_sidney",     TEMPLATE_NO,  LEVEL_1, (1, 1, "ALSA | JACK"), ("", "https://librazik.tuxfamily.org/doc3/logiciels/monobristol") ],
 #[ "bristol", "Commodore-64 SID polysynth",     "Synthétiseur", "melbourne",  "bristol_sidney",     TEMPLATE_NO,  LEVEL_1, (1, 1, "ALSA | JACK"), ("", "") ], #FIXME - needs icon
 #[ "bristol", "Bristol Granular Synthesiser",   "Synthétiseur", "granular",   "bristol_granular",   TEMPLATE_NO,  LEVEL_1, (1, 1, "ALSA | JACK"), ("", "") ],
 #[ "bristol", "Bristol Realtime Mixer",         "Synthétiseur", "mixer",      "bristol_mixer",      TEMPLATE_NO,  LEVEL_1, (1, 1, "ALSA | JACK"), ("", "http://bristol.sf.net/mixer.html") ],
]

iBristol_Package, iBristol_AppName, iBristol_Type, iBristol_ShortName, iBristol_Icon, iBristol_Template, iBristol_Level, iBristol_Features, iBristol_Docs = range(0, len(list_Bristol[0]))

# -------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
# Effect

# (S, MIDI-Mode) -> (Stereo, MIDI-Mode)

list_Effect = [
  # Package                 AppName                          Type                   Binary                                          Icon                Template?     Level    (S, MIDI-Mode)      (doc,                                                                  website)
  [ "ambdec",               "AmbDec",                     "Décodeur ambisonique",   "ambdec",                                       "ambdec", TEMPLATE_NO,  LEVEL_0, (1, "---"),  ("", "https://librazik.tuxfamily.org/doc3/logiciels/ambdec") ],

  [ "guitarix",             "Guitarix",              "Effets de guitare",           "guitarix",                                     "gx_head",          TEMPLATE_NO,  LEVEL_0, (0, "JACK"),        ("", "https://librazik.tuxfamily.org/doc3/logiciels/guitarix") ],

  [ "fogpad-port",          "FogPad",                        "Reverb",              "fogpad",                                generic_audio_icon,          TEMPLATE_NO,  LEVEL_0, (0, "JACK"),        ("", "https://librazik.tuxfamily.org/doc3/logiciels/fogpad") ],

  [ "freqtweak",  "Freqtweak",  "Manipulation spectrale audio en temps réel basée sur la FFT",  "freqtweak",      "freqtweak_logo32x18", TEMPLATE_NO,  LEVEL_0, (1, "---"),                      ("", "https://librazik.tuxfamily.org/doc3/logiciels/freqtweak") ],

  [ "jamin",                "Jamin",                         "Mastérisation",       "jamin",                                        "jamin",            TEMPLATE_NO,  LEVEL_0, (1, "---"),         ("", "https://librazik.tuxfamily.org/doc3/logiciels/jamin") ],

  [ "lsp-plugins",          "LSP comp-delay-mono",           "Compresseur",         "lsp-plugins-comp-delay-mono",                  generic_audio_icon, TEMPLATE_NO, LEVEL_0, (0, "---"),          ("", "https://librazik.tuxfamily.org/doc3/logiciels/lsp-plugins/verzoegerungsausgleicher_mono_-_delay_compensator_mono") ],

  [ "lsp-plugins",          "LSP comp-delay-stereo",         "Compresseur",         "lsp-plugins-comp-delay-stereo",                generic_audio_icon, TEMPLATE_NO, LEVEL_0, (1, "---"),          ("", "https://librazik.tuxfamily.org/doc3/logiciels/lsp-plugins/verzoegerungsausgleicher_stereo_-_delay_compensator_stereo") ],

  [ "lsp-plugins",          "LSP comp-delay-x2-stereo",      "Compresseur",         "lsp-plugins-comp-delay-x2-stereo",             generic_audio_icon, TEMPLATE_NO, LEVEL_0, (1, "---"),          ("", "https://librazik.tuxfamily.org/doc3/logiciels/lsp-plugins/verzoegerungsausgleicher_x2_stereo_-_delay_compensator_x2_stereo") ],

  [ "lsp-plugins",          "LSP phase-detector",            "Détecteur de phase",  "lsp-plugins-phase-detector",                   generic_audio_icon, TEMPLATE_NO, LEVEL_0, (1, "---"),          ("", "https://librazik.tuxfamily.org/doc3/logiciels/lsp-plugins/phasendetektor_-_phase_detector") ],

  [ "dpf-plugins",          "MVerb",                 "Effet de réverbération",      "MVerb",                                        "mverb",            TEMPLATE_NO,  LEVEL_0, (1, "---"),     ("", "https://librazik.tuxfamily.org/doc3/logiciels/dpf-plugins/mverb") ],

  [ "paulstretch",          "PaulStretch",                 "Étirement extrême",     "paulstretch",                                  "paulstretch",      TEMPLATE_NO,  LEVEL_0, (1, "---"),     ("", "https://librazik.tuxfamily.org/doc3/logiciels/paulstretch") ],

  [ "radium-compressor",    "Radium Compressor",            "Compresseur",          "radium_compressor",     "/usr/share/pixmaps/radium-compressor.xpm", TEMPLATE_NO,  LEVEL_0, (1, "---"),  ("", "https://librazik.tuxfamily.org/doc3/logiciels/radium-compressor") ],

  [ "rakarrack",            "Rakarrack",                     "Effets de guitare",   "rakarrack",             "icono_rakarrack_128x128",        TEMPLATE_NO,  LEVEL_0, (1, "ALSA + JACK"), ("", "https://librazik.tuxfamily.org/doc3/logiciels/rakarrack") ],

  [ "tap-reverbed",         "Reverbed",              "Effets de réverbération",     "reverbed",               "reverbed",        TEMPLATE_NO,  LEVEL_0, (1, "---"),    ("", "https://librazik.tuxfamily.org/doc3/logiciels/tap-reverbed") ],

  [ "snokoder",             "SnoKoder",             "Vocodeur",        "snokoder",                      "snokoder",         TEMPLATE_NO,  LEVEL_0, (0, "ALSA"),  ("", "https://librazik.tuxfamily.org/doc3/logiciels/snokoder") ],

  [ "x42-plugins",          "X42 - Darc",                    "Compresseur",         "x42-darc",            "x42-darc",         TEMPLATE_NO,  LEVEL_0, (0, "---"),          ("", "https://librazik.tuxfamily.org/doc3/logiciels/x42-plugins/x42-darc.lv2") ],

  [ "x42-plugins",          "X42 - Fil4 mono",    "Égaliseur 4 bandes",      "x42-fil4",                "x42-fil4",         TEMPLATE_NO,  LEVEL_0, (0, "---"),          ("", "https://librazik.tuxfamily.org/doc3/logiciels/x42-plugins/x42-4_band_parametric_eq") ],

  [ "x42-plugins",          "X42 - Fil4 stéréo",  "Égaliseur 4 bandes",      "x42-fil4 1",              "x42-fil4",         TEMPLATE_NO,  LEVEL_0, (1, "---"),          ("", "https://librazik.tuxfamily.org/doc3/logiciels/x42-plugins/x42-4_band_parametric_eq") ],

  [ "x42-plugins",          "X42 - Fat1",                    "Auto-tuner",          "x42-fat1",                                     "x42-fat1",         TEMPLATE_NO,  LEVEL_0, (0, "---"),  ("", "https://librazik.tuxfamily.org/doc3/logiciels/x42-plugins/x42-fat1") ],

  [ "setbfree",             "X42 - Whirl",        "Émulateur de cabine Leslie",     "x42-whirl",                                    "x42-whirl",        TEMPLATE_NO,  LEVEL_0, (0, "---"),  ("", "https://librazik.tuxfamily.org/doc3/logiciels/setbfree/x42-whirl") ],

  [ "zam-plugins",          "ZamAutoSat",                    "Saturateur",           "ZamAutoSat",                                   "zam",              TEMPLATE_NO,  LEVEL_0, (0, "---"),      ("", "https://librazik.tuxfamily.org/doc3/logiciels/zam-plugins/zamautosat") ],

  [ "zam-plugins",          "ZamComp",                       "Compresseur mono",     "ZamComp",                                      "zam",              TEMPLATE_NO,  LEVEL_0, (0, "---"),      ("", "https://librazik.tuxfamily.org/doc3/logiciels/zam-plugins/zamcomp") ],

  [ "zam-plugins",          "ZamCompX2",                     "Compresseur stéréo",   "ZamCompX2",                                    "zam",              TEMPLATE_NO,  LEVEL_0, (1, "---"),      ("", "https://librazik.tuxfamily.org/doc3/logiciels/zam-plugins/zamcompx2") ],

  [ "zam-plugins",          "ZamDelay",                      "Délai",                "ZamDelay",                                     "zam",              TEMPLATE_NO,  LEVEL_0, (0, "---"),      ("", "https://librazik.tuxfamily.org/doc3/logiciels/zam-plugins/zamdelay") ],

  [ "zam-plugins",          "ZamDynamicEQ",            "Égaliseur mono dynamique",   "ZamDynamicEQ",                                 "zam",              TEMPLATE_NO,  LEVEL_0, (0, "---"),      ("", "https://librazik.tuxfamily.org/doc3/logiciels/zam-plugins/zamdynamiceq") ],

  [ "zam-plugins",          "ZamEQ2",                        "Égaliseur 2 bandes",   "ZamEQ2",                                       "zam",              TEMPLATE_NO,  LEVEL_0, (0, "---"),      ("", "https://librazik.tuxfamily.org/doc3/logiciels/zam-plugins/zameq2") ],

  [ "zam-plugins",          "ZamGate",                       "Gate mono",            "ZamGate",                                      "zam",              TEMPLATE_NO,  LEVEL_0, (0, "---"),      ("", "https://librazik.tuxfamily.org/doc3/logiciels/zam-plugins/zamgate") ],

  [ "zam-plugins",          "ZamGateX2",                     "Gate stéréo",          "ZamGateX2",                                    "zam",              TEMPLATE_NO,  LEVEL_0, (1, "---"),      ("", "https://librazik.tuxfamily.org/doc3/logiciels/zam-plugins/zamgatex2") ],

  [ "zam-plugins",          "ZamGEQ31",                      "Égaliseur 31 bandes",  "ZamGEQ31",                                     "zam",              TEMPLATE_NO,  LEVEL_0, (0, "---"),      ("", "https://librazik.tuxfamily.org/doc3/logiciels/zam-plugins/zamgeq31") ],

  [ "zam-plugins",          "ZamHeadX2",                     "Élargisseur stéréo",   "ZamHeadX2",                                    "zam",              TEMPLATE_NO,  LEVEL_0, (1, "---"),      ("", "https://librazik.tuxfamily.org/doc3/logiciels/zam-plugins/zamheadx2") ],

  [ "zam-plugins",          "ZaMaximX2",                     "Maximiseur",           "ZaMaximX2",                                    "zam",              TEMPLATE_NO,  LEVEL_0, (1, "---"),      ("", "https://librazik.tuxfamily.org/doc3/logiciels/zam-plugins/zamaximx2") ],

  [ "zam-plugins",          "ZaMultiComp",               "Multi-compresseur mono",   "ZaMultiComp",                                  "zam",              TEMPLATE_NO,  LEVEL_0, (0, "---"),      ("", "https://librazik.tuxfamily.org/doc3/logiciels/zam-plugins/zamulticomp") ],

  [ "zam-plugins",          "ZaMultiCompX2",           "Multi-compresseur stéréo",   "ZaMultiCompX2",                                "zam",              TEMPLATE_NO,  LEVEL_0, (1, "---"),   ("", "https://librazik.tuxfamily.org/doc3/logiciels/zam-plugins/zamulticompx2") ],

  [ "zam-plugins",          "ZamPhono",                      "Filtres phono",        "ZamPhono",                                     "zam",              TEMPLATE_NO,  LEVEL_0, (0, "---"),      ("", "https://librazik.tuxfamily.org/doc3/logiciels/zam-plugins/zamphono") ],

  [ "zam-plugins",          "ZamTube",               "Émulateur d'ampli à tube",     "ZamTube",                                      "zam",              TEMPLATE_NO,  LEVEL_0, (0, "JACK"),     ("", "https://librazik.tuxfamily.org/doc3/logiciels/zam-plugins/zamtube") ],

  [ "zam-plugins",          "ZamVerb",                       "Réverbération",        "ZamVerb",                                      "zam",              TEMPLATE_NO,  LEVEL_0, (1, "JACK"),     ("", "https://librazik.tuxfamily.org/doc3/logiciels/zam-plugins/zamverb") ],

  [ "zita-at1",             "Zita-at1",         "Auto-tuner",                   "zita-at1",                             "zita-at1",         TEMPLATE_NO,  LEVEL_0, (0, "JACK"), ("", "https://librazik.tuxfamily.org/doc3/logiciels/zita-at1") ],

  [ "zita-rev1",            "Zita-rev1",        "Réverbération",                "zita-rev1",                            "zita-rev1",        TEMPLATE_NO,  LEVEL_0, (1, "JACK"), ("", "https://librazik.tuxfamily.org/doc3/logiciels/zita-rev1") ],

  [ "zita-rev1",            "Zita-rev1",        "Réverbération - ambisonique",  "zita-rev1 -B",                         "zita-rev1",        TEMPLATE_NO,  LEVEL_0, (1, "JACK"), ("", "https://librazik.tuxfamily.org/doc3/logiciels/zita-rev1") ],

]

iEffect_Package, iEffect_AppName, iEffect_Type, iEffect_Binary, iEffect_Icon, iEffect_Template, iEffect_Level, iEffect_Features, iEffect_Docs = range(0, len(list_Effect[0]))

# -------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
# Tool

# (MIDI-M, T) -> (MIDI-Mode, Transport)

list_Tool = [
  # Package              AppName                         Type                   Binary                    Icon                Template?     Level    (MIDI-M, T)  (doc,                                                         website)
  [ "aliki",             "Aliki (ALSA)",  "Outil de mesure de réponse impulsionnelle", "aliki -a",               "aliki_32x32",      TEMPLATE_NO,  LEVEL_0, ("---", 0),  ("", "https://librazik.tuxfamily.org/doc3/logiciels/aliki") ],

  [ "aliki",             "Aliki (JACK)",  "Outil de mesure de réponse impulsionnelle", "aliki -j",               "aliki_32x32",      TEMPLATE_NO,  LEVEL_0, ("---", 0),  ("", "https://librazik.tuxfamily.org/doc3/logiciels/aliki") ],

  [ "arpage",            "Arpage",                       "Arpégiateur MIDI",    "arpage",                 "arpage",           TEMPLATE_NO,  LEVEL_0, ("JACK", 1), ("",                                                                 "") ],
  [ "arpage",            "Zonage",                       "Traceur MIDI",        "zonage",                 "zonage",           TEMPLATE_NO,  LEVEL_0, ("JACK", 0), ("",                                                                 "") ],

  [ "audacity",          "Audacity",                     "Éditeur audio",       "audacity",               "audacity",         TEMPLATE_NO,  LEVEL_0, ("---", 0),  ("", "https://librazik.tuxfamily.org/doc3/logiciels/audacity") ],

  [ "bitmeter",          "Bitmeter",         "Outil de diagnostique pour JACK", "bitmeter",               "bitmeter",         TEMPLATE_NO,  LEVEL_0, ("---", 0),  ("", "https://librazik.tuxfamily.org/doc3/logiciels/bitmeter") ],

  [ "cadence",           "Cadence",                      "Boîte à outils JACK", "cadence",                "cadence",          TEMPLATE_NO,  LEVEL_0, ("---", 0),  ("", "https://librazik.tuxfamily.org/doc3/logiciels/suite-cadence/cadence") ],
  [ "cadence-tools",     "Cadence XY-Controller",        "Contrôleur XY",       "cadence-xycontroller",   "cadence",          TEMPLATE_NO,  LEVEL_0, ("JACK", 0), ("", "https://librazik.tuxfamily.org/doc3/logiciels/suite-cadence/cadence-xycontroller") ],
  [ "catia",             "Catia",                        "Baie de brassage",    "catia",                  "catia",            TEMPLATE_NO,  LEVEL_0, ("JACK | ALSA", 1), ("", "https://librazik.tuxfamily.org/doc3/logiciels/suite-cadence/catia") ],
  [ "carla-control",     "Carla OSC Control",            "Contrôle OSC",        "carla-control",          "carla-control",    TEMPLATE_NO,  LEVEL_0, ("JACK", 1), ("", "https://librazik.tuxfamily.org/doc3/logiciels/carla-ensemble/carla-control") ],

  [ "denemo",            "Denemo",                      "Éditeur de partition", "denemo",                 "denemo",           TEMPLATE_NO,  LEVEL_0, ("---", 0),  ("", "https://librazik.tuxfamily.org/doc3/logiciels/denemo") ],

  [ "digitalscratch",   "Digital-Scratch",   "DJ avec vinyles time-codé",   "digitalscratch",   "digitalscratch-icon_2decks", TEMPLATE_NO,  LEVEL_0, ("---", 0),  ("", "https://librazik.tuxfamily.org/doc3/logiciels/digital-scratch") ],

  [ "drumstick-tools",   "Drumstick Virtual Piano",      "Clavier virtuel",     "drumstick-vpiano",       "drumstick",        TEMPLATE_NO,  LEVEL_0, ("ALSA", 0), ("", "https://librazik.tuxfamily.org/doc3/logiciels/drumstick-tools") ],

  [ "easytag",    "EasyTAG",   "Gestion des méta-données de fichiers audio",    "easytag",                "easytag",          TEMPLATE_NO,  LEVEL_0, ("---", 0),  ("", "https://librazik.tuxfamily.org/doc3/logiciels/easytag") ],

  [ "etktab",            "eTktab",                    "Éditeur de partition",   "eTktab",                 "eTktab",           TEMPLATE_NO,  LEVEL_0, ("---", 0),  ("", "https://librazik.tuxfamily.org/doc3/logiciels/etktab") ],

  [ "ebumeter",          "Ebumeter",        "Mesureur de sonie  EBU-r128",      "ebumeter",               "ebumeter32x32",    TEMPLATE_NO,  LEVEL_0, ("---", 0),  ("", "https://librazik.tuxfamily.org/doc3/logiciels/ebumeter") ],

  [ "alsa-tools-gui",    "Echomixer",                    "Mixeur Echoaudio",    "echomixer",              "alsa-tools",       TEMPLATE_NO,  LEVEL_0, ("---", 0),  ("", "https://librazik.tuxfamily.org/doc3/logiciels/echomixer") ],

  [ "elektroid",   "Elektroid",   "Logiciel pour les périphériques Elektron",   "elektroid",              "elektroid",        TEMPLATE_NO,  LEVEL_0, ("---", 0),  ("", "https://librazik.tuxfamily.org/doc3/logiciels/elektroid") ],

  [ "alsa-tools-gui",    "Envy24Control",                "Mixeur Ice1712",      "envy24control",          "alsa-tools",       TEMPLATE_NO,  LEVEL_0, ("---", 0),  ("", "https://librazik.tuxfamily.org/doc3/logiciels/envy24control") ],

  [ "audio-recorder",    "Audio-recorder",               "Enregistreur audio",  "audio-recorder",         "audio-recorder",   TEMPLATE_NO,  LEVEL_0, ("---", 0),  ("", "https://librazik.tuxfamily.org/doc3/logiciels/audio-recorder") ],

  [ "ffado-mixer-qt4",   "FFADO-mixer",      "Mixeur pour interfaces firewire", "ffado-mixer",            "hi64-apps-ffado",  TEMPLATE_NO,  LEVEL_0, ("---", 0),  ("", "https://librazik.tuxfamily.org/doc3/logiciels/ffado-mixer") ],

  [ "fmit",          "Music Instrument Tuner",     "Accordeur d'instrument",    "fmit",                   "fmit",             TEMPLATE_NO,  LEVEL_0, ("---", 0),  ("", "https://librazik.tuxfamily.org/doc3/logiciels/fmit") ],

  [ "frescobaldi",       "Frescobaldi",            "Éditeur de partition",      "frescobaldi", "org.frescobaldi.Frescobaldi", TEMPLATE_NO,  LEVEL_0, ("---", 0),  ("", "https://librazik.tuxfamily.org/doc3/logiciels/frescobaldi") ],

  [ "gdigi",           "Gdigi",      "Contrôle de certaines pédales Digitech",  "gdigi",                   "gdigi",           TEMPLATE_NO,  LEVEL_0, ("---", 0),  ("", "https://librazik.tuxfamily.org/doc3/logiciels/gdigi") ],

  [ "gigedit",           "Gigedit",                  "Éditeur d'instrument",    "gigedit",                generic_audio_icon, TEMPLATE_NO,  LEVEL_0, ("---", 0),  ("", "https://librazik.tuxfamily.org/doc3/logiciels/gigedit") ],

  [ "gjacktransport",    "GJackClock",                   "Outil de transport",  "gjackclock",             "gjackclock",       TEMPLATE_NO,  LEVEL_0, ("---", 1),  ("", "https://librazik.tuxfamily.org/doc3/logiciels/gjackclock") ],
  [ "gjacktransport",    "GJackTransport",               "Outil de transport",  "gjacktransport",         "gjacktransport",   TEMPLATE_NO,  LEVEL_0, ("---", 1),  ("", "https://librazik.tuxfamily.org/doc3/logiciels/gjacktransport") ],

  [ "gladish",           "Gladish",         "Gestionnaire de studio LADISH",    "gladish",                "gladish",          TEMPLATE_NO,  LEVEL_0, ("JACK | ALSA", 0), ("", "https://librazik.tuxfamily.org/doc3/logiciels/gladish") ],

  [ "dpf-plugins",       "glBars",                       "Visualiseur audio",   "glBars",                 "glbars",           TEMPLATE_NO,  LEVEL_0, ("JACK", 0), ("", "https://librazik.tuxfamily.org/doc3/logiciels/dpf-plugins/glbars") ],

  [ "gmidimonitor",   "Gmidimonitor (ALSA)",  "Moniteur d'évènement MIDI-ALSA", "gmidimonitor --alsa",  "gmidimonitor_32x32", TEMPLATE_NO,  LEVEL_0, ("JACK | ALSA", 0), ("", "https://librazik.tuxfamily.org/doc3/logiciels/gmidimonitor") ],
  [ "gmidimonitor",   "Gmidimonitor (JACK)",  "Moniteur d'évènement MIDI-JACK", "gmidimonitor --jack",  "gmidimonitor_32x32", TEMPLATE_NO,  LEVEL_0, ("JACK | ALSA", 0), ("", "https://librazik.tuxfamily.org/doc3/logiciels/gmidimonitor") ],

  [ "gwc",               "Gtk Wave Cleaner",     "Nettoyeur de fichier audio",  "gtk-wave-cleaner",       "gtk-wave-cleaner", TEMPLATE_NO,  LEVEL_0, ("---", 0),  ("", "https://librazik.tuxfamily.org/doc3/logiciels/gwc") ],

  [ "gninjam",           "Gtk NINJAM client",         "Collaboration musicale", "gninjam",                "gninjam",          TEMPLATE_NO,  LEVEL_0, ("---", 1),  ("", "https://librazik.tuxfamily.org/doc3/logiciels/gninjam") ],

  [ "gtklick",           "Gtklick",                      "Métronome",           "gtklick",                "gtklick",          TEMPLATE_NO,  LEVEL_0, ("---", 0),  ("", "https://librazik.tuxfamily.org/doc3/logiciels/gtklick") ],

  [ "gxtuner",           "Gxtuner",               "Accordeur d'instrument",     "gxtuner",                "gxtuner",          TEMPLATE_NO,  LEVEL_JS, ("---", 0),  ("", "https://librazik.tuxfamily.org/doc3/logiciels/gxtuner") ],

  [ "handbrake",  "Handbrake",  "Transcode les DVD, Bluray, et autres medias",  "ghb",                    "hb-icon",          TEMPLATE_NO,  LEVEL_0, ("---", 0),  ("", "https://librazik.tuxfamily.org/doc3/logiciels/handbrake") ],

  [ "alsa-tools-gui",    "HdaJackRetask",    "Contrôle du matériel Intel HDA",  "hdajackretask",          "alsa-tools",       TEMPLATE_NO,  LEVEL_0, ("---", 0),  ("", "https://librazik.tuxfamily.org/doc3/logiciels/hdajackretask") ],
  [ "alsa-tools-gui",    "HDSPconf",         "Contrôle des matériels HDSP",     "hdspconf",               "alsa-tools",       TEMPLATE_NO,  LEVEL_0, ("---", 0),  ("", "https://librazik.tuxfamily.org/doc3/logiciels/hdspconf") ],
  [ "alsa-tools-gui",    "HDSPmixer",        "Mixeur des matériels HDSP",       "hdspmixer",              "alsa-tools",       TEMPLATE_NO,  LEVEL_0, ("---", 0),  ("", "https://librazik.tuxfamily.org/doc3/logiciels/hdspmixer") ],

  [ "jaaa",              "Jaaa-ALSA",    "Analyse/génère un signal audio",      "jaaa -A",                "jaaa",             TEMPLATE_NO,  LEVEL_0, ("---", 0),  ("", "https://librazik.tuxfamily.org/doc3/logiciels/jaaa") ],
  [ "jaaa",              "Jaaa-JACK",    "Analyse/génère un signal audio",      "jaaa -J",                "jaaa",             TEMPLATE_NO,  LEVEL_0, ("---", 0),  ("", "https://librazik.tuxfamily.org/doc3/logiciels/jaaa") ],

  [ "jack-capture", "Jack-Capture-GUI", "Interface graphique pour capturer l'audio de JACK", "jack_capture_gui", "jack_capture_gui", TEMPLATE_NO,  LEVEL_0, ("---", 0),  ("", "https://librazik.tuxfamily.org/doc3/logiciels/jack_capture_gui") ],

  [ "jackeq",            "JackEQ",   "Interface graphique de console de DJ",    "jackeq", "/usr/share/pixmaps/logo-jackeq-s.png", TEMPLATE_NO,  LEVEL_0, ("---", 0),  ("", "https://librazik.tuxfamily.org/doc3/logiciels/jackeq") ],

  [ "jack-keyboard",     "Jack Keyboard",           "Clavier virtuel",          "jack-keyboard",          "jack-keyboard",    TEMPLATE_NO,  LEVEL_0, ("JACK", 0), ("", "https://librazik.tuxfamily.org/doc3/logiciels/jack_keyboard") ],

  [ "jack-mixer",        "Jack Mixer",              "Mixeur",                   "jack_mixer",             "jack_mixer",       TEMPLATE_NO,  LEVEL_NSM, ("JACK", 0), ("", "https://librazik.tuxfamily.org/doc3/logiciels/jack-mixer") ],

  [ "jamulus",           "Jamulus",                 "Collaboration musicale",   "jamulus",                "jamulus",          TEMPLATE_NO,  LEVEL_0, ("---", 0),  ("", "https://librazik.tuxfamily.org/doc3/logiciels/jamulus") ],

  [ "japa",              "Japa-ALSA",               "Analyse un signal audio",  "japa -A",                "japa",             TEMPLATE_NO,  LEVEL_0, ("---", 0),  ("", "https://librazik.tuxfamily.org/doc3/logiciels/japa") ],
  [ "japa",              "Japa-JACK",               "Analyse un signal audio",  "japa -J",                "japa",             TEMPLATE_NO,  LEVEL_0, ("---", 0),  ("", "https://librazik.tuxfamily.org/doc3/logiciels/japa") ],

  [ "jkmeter",           "Jkmeter",                 "Mesureur de niveau audio", "jkmeter",                "jkmeter32x32",     TEMPLATE_NO,  LEVEL_0, ("---", 0),  ("", "https://librazik.tuxfamily.org/doc3/logiciels/jkmeter") ],

  [ "jmeters",           "Jmeters", "Mesureur de signaux audio multi-canaux",   "jmeters",                "jmeters_32x32",    TEMPLATE_NO,  LEVEL_0, ("---", 0),  ("", "https://librazik.tuxfamily.org/doc3/logiciels/jmeters") ],

#  [ "jnoise",            "Jnoise",            "White & Pink Noise Generation", "jnoise",                 generic_audio_icon, TEMPLATE_NO,  LEVEL_0, ("---", 0),  ("",                                                          "http://kokkinizita.linuxaudio.org/linuxaudio/index.html") ],

  [ "jnoisemeter",       "Jnoisemeter",   "Mesureur de signaux audio de test",  "jnoisemeter",           "jnoisemeter_32x32", TEMPLATE_NO,  LEVEL_0, ("---", 0),  ("", "https://librazik.tuxfamily.org/doc3/logiciels/jnoisemeter") ],

  [ "kmetronome",        "KMetronome",                   "Métronome",           "kmetronome",             "kmetronome",       TEMPLATE_NO,  LEVEL_0, ("ALSA", 0), ("",                                                                       "") ],
  [ "kmidimon",          "KMidimon",                     "Moniteur MIDI",       "kmidimon",               "kmidimon",         TEMPLATE_NO,  LEVEL_0, ("ALSA", 0), ("",                                                                       "") ],

  [ "laditools",         "LADI Log",                     "Visualiseur de log",  "ladi-system-log",        "ladi-system-log",  TEMPLATE_NO,  LEVEL_0, ("---", 0),  ("", "https://librazik.tuxfamily.org/doc3/logiciels/laditools/ladi-system-log") ],
  [ "laditools",         "LADI Tray",                "Gestionnaire de session", "ladi-system-tray",       "laditools",        TEMPLATE_NO,  LEVEL_0, ("---", 0),  ("", "https://librazik.tuxfamily.org/doc3/logiciels/laditools/ladi-system-tray") ],

  [ "lenmus-all",        "Lenmus",       "Étude de la théorie musicale",        "lenmus",                 "lenmus",           TEMPLATE_NO,  LEVEL_0, ("---", 0),  ("",                                                                       "") ],

  [ "lingot",            "Lingot",                 "Accordeur d'instrument",    "lingot",                "org.nongnu.lingot", TEMPLATE_NO,  LEVEL_0, ("---", 0),  ("", "https://librazik.tuxfamily.org/doc3/logiciels/lingot") ],

  [ "linux-show-player", "Linux Show Player",     "Lecteur d'échantillons",     "linux-show-player",      "linuxshowplayer",  TEMPLATE_NO,  LEVEL_0, ("JACK", 0), ("", "https://librazik.tuxfamily.org/doc3/logiciels/linux-show-player") ],

  [ "lives",             "LiVES",                        "VJ / éditeur vidéo",  "lives",                  "lives",            TEMPLATE_NO,  LEVEL_0, ("---", 1),  ("",                                                                       "") ],

  [ "luppp",             "Luppp",                        "Boucleur audio",      "luppp",                  "luppp",            TEMPLATE_NO,  LEVEL_NSM, ("---", 0),  ("", "https://librazik.tuxfamily.org/doc3/logiciels/luppp") ],

  [ "mamba",             "Mamba",                        "Virtual Keyboard",    "mamba",                  "Mamba",            TEMPLATE_NO,  LEVEL_NSM, ("ALSA", 0), ("",                                                                       "") ],

  [ "mcpdisp",         "MCP Disp",           "Mackie Display Emulator",         "mcpdisp",                "mcpdisp",          TEMPLATE_NO,  LEVEL_0, ("---", 0),  ("",                                                                       "") ],

  [ "meterbridge",       "MeterBridge Classic VU",                 "VU / analyseur de pic",      "meterbridge -t vu :",            "meterbridge32x32",     TEMPLATE_NO,  LEVEL_0,    ("---", 0),    ("", "https://librazik.tuxfamily.org/doc3/logiciels/meterbridge") ],
  [ "meterbridge",       "MeterBridge PPM Meter",                  "VU / analyseur de pic",      "meterbridge -t ppm :",           "meterbridge32x32",     TEMPLATE_NO,  LEVEL_0,    ("---", 0),    ("", "https://librazik.tuxfamily.org/doc3/logiciels/meterbridge") ],
  [ "meterbridge",       "MeterBridge Digital Peak Meter",         "VU / analyseur de pic",      "meterbridge -t dpm -c 2 : :",    "meterbridge32x32",     TEMPLATE_NO,  LEVEL_0,    ("---", 0),    ("", "https://librazik.tuxfamily.org/doc3/logiciels/meterbridge") ],
  [ "meterbridge",       "MeterBridge 'Jellyfish' Phase Meter",    "VU / analyseur de pic",      "meterbridge -t jf -c 2 : :",     "meterbridge32x32", TEMPLATE_NO, LEVEL_0,     ("---", 0),    ("", "https://librazik.tuxfamily.org/doc3/logiciels/meterbridge") ],
  [ "meterbridge",      "MeterBridge Oscilloscope Meter",          "VU / analyseur de pic",      "meterbridge -t sco :",           "meterbridge32x32",     TEMPLATE_NO,  LEVEL_0,    ("---", 0),    ("", "https://librazik.tuxfamily.org/doc3/logiciels/meterbridge") ],

  [ "mhwaveedit",        "MhWaveEdit",                   "Éditeur audio",       "mhwaveedit",             "mhwaveedit",       TEMPLATE_NO,  LEVEL_0, ("---", 0),  ("", "https://librazik.tuxfamily.org/doc3/logiciels/mhwaveedit") ],

  [ "mixxx",             "Mixxx",                        "DJ",                  "mixxx",                  "mixxx_icon",       TEMPLATE_NO,  LEVEL_0, ("ALSA", 0), ("", "https://librazik.tuxfamily.org/doc3/logiciels/mixxx") ],

  [ "mpk-m2-editor",     "MPK M2 Editor",                "Editor for MPK M2",   "mpk_m2-editor",          "mpk-m2-editor",    TEMPLATE_NO,  LEVEL_0, ("---", 0),  ("",                                                                       "") ],

  [ "mudita24",          "Mudita24",        "Mixeur pour interfaces Ice1712",   "mudita24",               "mudita24",         TEMPLATE_NO,  LEVEL_0, ("---", 0),  ("", "https://librazik.tuxfamily.org/doc3/logiciels/mudita24") ],

  [ "nano-basket",       "Nano-Basket",          "Gestion de matériels Nano",   "nano-basket",            "nano-basket",      TEMPLATE_NO,  LEVEL_0, ("---", 0),  ("", "https://librazik.tuxfamily.org/doc3/logiciels/nano-basket") ],

  [ "non-mixer",         "Non-Mixer",                    "Mixeur",              "non-mixer",              "non-mixer",        TEMPLATE_NO,  LEVEL_0, ("CV",   0), ("", "https://librazik.tuxfamily.org/doc3/logiciels/non-suite/non-mixer") ],

  [ "nootka",   "Nootka",   "Apprendre la notation musicale sur partitions",    "nootka",                 "nootka",           TEMPLATE_NO,  LEVEL_0, ("---", 0),  ("", "https://librazik.tuxfamily.org/doc3/logiciels/nootka") ],

  [ "patchage",          "Patchage",                     "Baie de brassage",    "patchage",               "patchage",         TEMPLATE_NO,  LEVEL_0, ("ALSA + JACK", 0), ("", "https://librazik.tuxfamily.org/doc3/logiciels/patchage") ],

  [ "pd-l2ork", "Pd-L2Ork", "Environnement Pure-Data", "pd-l2ork -rt -audiobuf 20 -inchannels 2 -outchannels 2 -alsamidi -mididev 0 %U", "pd-l2ork", TEMPLATE_NO,  LEVEL_0, ("ALSA", 0), ("", "https://librazik.tuxfamily.org/doc3/logiciels/pd-l2ork") ],

  [ "pianobooster",      "Piano Booster",                "Professeur de piano", "pianobooster",           "pianobooster",     TEMPLATE_NO,  LEVEL_0, ("ALSA", 0), ("", "https://librazik.tuxfamily.org/doc3/logiciels/pianobooster") ],

  [ "playitslowly",      "Play it Slowly",               "Lecteur-étireur",     "playitslowly",       "ch.x29a.playitslowly", TEMPLATE_NO,  LEVEL_0, ("---", 0),  ("", "https://librazik.tuxfamily.org/doc3/logiciels/playitslowly") ],

  [ "dpf-plugins",       "ProM",                   "Visualiseur de musique",    "ProM",                   "prom",             TEMPLATE_NO,  LEVEL_0, ("JACK", 0),  ("", "https://librazik.tuxfamily.org/doc3/logiciels/dpf-plugins/prom") ],

  [ "qamix",             "QAMix",                        "Mixeur",              "qamix",                  "qamix",            TEMPLATE_NO,  LEVEL_0, ("ALSA", 0),  ("",                                                                      "") ],
  [ "qarecord",          "QARecord",                     "Enregistreur",        "qarecord --jack",        "qarecord_48",      TEMPLATE_NO,  LEVEL_0, ("ALSA", 0),  ("",                                                                      "") ],

  [ "qjackctl",          "QJackControl",                 "Contrôle JACK",       "qjackctl",               "qjackctl",         TEMPLATE_NO,  LEVEL_0, ("ALSA + JACK", 1), ("", "https://librazik.tuxfamily.org/doc3/logiciels/qjackctl") ],

#  [ "qjackrcd",        "QJackRcd",                       "Enregistrement",      "qjackrcd",               "qjackrcd",         TEMPLATE_NO,  LEVEL_0, ("---",  1),        ("", "https://librazik.tuxfamily.org/doc3/logiciels/qjackrcd") ],

  [ "qlcplus",           "QLCplus",         "Contrôleur de lumières-spectacle", "qlcplus",                "qlcplus",          TEMPLATE_NO,  LEVEL_0, ("ALSA", 0), ("", "https://librazik.tuxfamily.org/doc3/logiciels/qlcplus") ],

  [ "qlcplus",  "Éditeur d'équipement QLC+",  "Éditeur d'équipement pour QLC+", "qlcplus-fixtureeditor",  "qlcplus-fixtureeditor", TEMPLATE_NO,  LEVEL_0, ("---", 0),  ("", "https://librazik.tuxfamily.org/doc3/logiciels/qlcplus-fixtureeditor") ],

  [ "qloud",             "Qloud",       "Outil de mesure audio pour JACK",      "qloud",                  "qloud",            TEMPLATE_NO,  LEVEL_0, ("---", 0),  ("", "https://librazik.tuxfamily.org/doc3/logiciels/qloud") ],

  [ "qmidiarp",          "QMidiArp",                     "Arpégiateur MIDI",    "qmidiarp",               "qmidiarp",         TEMPLATE_NO,  LEVEL_0, ("ALSA + JACK", 0), ("", "https://librazik.tuxfamily.org/doc3/logiciels/qmidiarp") ],

  [ "qmidiroute",   "QMidiRoute",   "Routeur MIDI et processeur d'événements",  "qmidiroute", "/usr/share/pixmaps/qmidiroute_32x32.xpm", TEMPLATE_NO,  LEVEL_0, ("ALSA", 0), ("", "https://librazik.tuxfamily.org/doc3/logiciels/qmidiroute") ],

  [ "qmidictl",          "QmidiCtl",   "Contrôleur MIDI à travers le réseau",   "qmidictl",               "qmidictl",         TEMPLATE_NO,  LEVEL_0, ("---", 0),  ("", "https://librazik.tuxfamily.org/doc3/logiciels/qmidictl") ],

  [ "qmidinet",        "QmidiNet",                "Passerelle réseau MIDI",     "qmidinet",               "qmidinet",         TEMPLATE_NO,  LEVEL_0, ("---", 0),  ("", "https://librazik.tuxfamily.org/doc3/logiciels/qmidinet") ],

  [ "qrest",           "Qrest",              "Calculette pour délai, LFO,...",  "qrest",                  "qrest",            TEMPLATE_NO,  LEVEL_0, ("---", 0),  ("", "https://librazik.tuxfamily.org/doc3/logiciels/qrest") ],

  [ "qxgedit",         "QXGedit",            "Contrôleur des matériels XG",     "qxgedit",                "qxgedit",          TEMPLATE_NO,  LEVEL_0, ("---", 0),  ("", "https://librazik.tuxfamily.org/doc3/logiciels/qxgedit") ],

  [ "raysession",      "Ray Session",        "Gestionnaire de session NSM",     "raysession",             "raysession",       TEMPLATE_NO,  LEVEL_0, ("---", 0),  ("", "https://librazik.tuxfamily.org/doc3/logiciels/ray_session") ],

  [ "recjack",         "RecJack",                        "Enregistreur",        "recjack",                "recjack",          TEMPLATE_NO,  LEVEL_0, ("---", 1),  ("", "https://librazik.tuxfamily.org/doc3/logiciels/recjack") ],

  [ "rezound",         "ReZound",                        "Éditeur audio",       "rezound",                "rezound32",        TEMPLATE_NO,  LEVEL_0, ("---", 0),  ("", "https://librazik.tuxfamily.org/doc3/logiciels/rezound") ],

  [ "alsa-tools-gui",  "RME Digi Control",   "Mixeur pour interfaces RME Digi", "rmedigicontrol",         "alsa-tools",       TEMPLATE_NO,  LEVEL_0, ("---", 0),  ("", "https://librazik.tuxfamily.org/doc3/logiciels/rmedigicontrol") ],

  [ "showq",           "ShowQ",                     "Lecteur d'échantillons",   "showq",                  "showq_32x32",      TEMPLATE_NO,  LEVEL_0, ("ALSA", 0), ("", "https://librazik.tuxfamily.org/doc3/logiciels/showq") ],

  [ "shuriken",        "Shuriken",                     "Trancheur de rythme",   "shuriken",               "shuriken",         TEMPLATE_NO,  LEVEL_1, ("JACK+ALSA", 1), ("", "https://librazik.tuxfamily.org/doc3/logiciels/shuriken") ],

  [ "simplescreenrecorder", "Simple Screen Recorder",  "Captureur d'écran",  "simplescreenrecorder", "simplescreenrecorder",  TEMPLATE_NO,  LEVEL_0, ("---", 0),  ("", "https://librazik.tuxfamily.org/doc3/logiciels/simple_screen_recorder") ],

  [ "smplayer",        "Smplayer",                       "Lecteur multimédia",  "smplayer",               "smplayer",         TEMPLATE_NO,  LEVEL_0, ("---", 0),  ("", "https://librazik.tuxfamily.org/doc3/logiciels/smplayer") ],

  [ "solfege",         "Solfege",                "Entraînement de l'oreille",   "solfege",                "solfege",          TEMPLATE_NO,  LEVEL_0, ("---", 0),  ("", "https://librazik.tuxfamily.org/doc3/logiciels/solfege") ],

  [ "songwrite",  "Songwrite 3",  "Lecteur et éditeur de tablature de guitare", "songwrite",              "songwrite3",       TEMPLATE_NO,  LEVEL_0, ("---", 0),  ("", "https://librazik.tuxfamily.org/doc3/logiciels/songwrite") ],

  [ "sonic-visualiser", "Sonic Visualiser", "Visualisation et analyse du signal", "sonic-visualiser",     "sv-icon",          TEMPLATE_NO,  LEVEL_0, ("JACK", 0), ("", "https://librazik.tuxfamily.org/doc3/logiciels/sonic-visualiser") ],

  [ "spek",            "Spek",                       "Analyseur de spectre",    "spek",                   "spek",             TEMPLATE_NO,  LEVEL_0, ("---", 0),  ("", "https://librazik.tuxfamily.org/doc3/logiciels/spek") ],

  [ "stretchplayer",   "Stretch Player",                "Lecteur-étireur",      "stretchplayer",          "stretchplayer",    TEMPLATE_NO,  LEVEL_0, ("---", 0),  ("", "https://librazik.tuxfamily.org/doc3/logiciels/stretchplayer") ],

  [ "swami",           "Swami",                  "Éditeur d'instruments SF2",   "swami",                  "swami",            TEMPLATE_NO,  LEVEL_0, ("ALSA", 0), ("", "https://librazik.tuxfamily.org/doc3/logiciels/swami") ],

  [ "tinyeartrainer", "Tiny Ear Trainer", "Outils d'entraînement de l'oreille", "tinyeartrainer",         "tinyeartrainer",   TEMPLATE_NO,  LEVEL_0, ("---", 0),  ("", "https://librazik.tuxfamily.org/doc3/logiciels/tinyeartrainer") ],

  [ "timemachine",  "TimeMachine",  "Enregistreur",  "timemachine",  "/usr/share/timemachine/pixmaps/timemachine-icon.png",   TEMPLATE_NO, LEVEL_0, ("---", 0), ("", "https://librazik.tuxfamily.org/doc3/logiciels/timemachine") ],

  [ "tmlauncher",      "TM Launcher",                      "Enregistreur",      "TMLauncher.py",          "TMLauncher",       TEMPLATE_NO,  LEVEL_0, ("---", 0),  ("", "https://librazik.tuxfamily.org/doc3/logiciels/tmlauncher") ],

  [ "tuxguitar",       "TuxGuitar",                "Partition de guitare",      "tuxguitar",              "tuxguitar",        TEMPLATE_NO,  LEVEL_0, ("---", 0),  ("", "https://librazik.tuxfamily.org/doc3/logiciels/tuxguitar") ],

  [ "vkeybd",          "Virtual Keyboard",              "Clavier virtuel",      "vkeybd",                 "vkeybd",           TEMPLATE_NO,  LEVEL_0, ("ALSA", 0), ("", "https://librazik.tuxfamily.org/doc3/logiciels/vkeybd") ],

  [ "vmpk",            "Virtual MIDI Piano Keyboard (ALSA)", "Clavier virtuel", "vmpk",                   "vmpk",             TEMPLATE_NO,  LEVEL_0, ("ALSA", 0), ("", "https://librazik.tuxfamily.org/doc3/logiciels/vkeybd") ],
  [ "vmpk-jack",       "Virtual MIDI Piano Keyboard (JACK)", "Clavier virtuel", "vmpk-jack",              "vmpk",             TEMPLATE_NO,  LEVEL_0, ("JACK", 0), ("", "https://librazik.tuxfamily.org/doc3/logiciels/vkeybd") ],

  [ "x42-plugins",     "X42 - StepSeq",           "Séquenceur pas à pas",       "x42-stepseq",            "x42-stepseq",      TEMPLATE_NO,  LEVEL_0, ("JACK", 0), ("", "https://librazik.tuxfamily.org/doc3/logiciels/x42-plugins/x42-stepseq") ],

  [ "x42-plugins",     "X42-Meter - EBU R128",    "Mesureur",                   "x42-meter",              "x42-meters",       TEMPLATE_NO,  LEVEL_0, ("---", 0),  ("", "https://librazik.tuxfamily.org/doc3/logiciels/x42-plugins/x42-ebu_r128_meter") ],

  [ "x42-plugins",     "X42-Meter - K20",         "Mesureur",                   "x42-meter 1",            "x42-meters",       TEMPLATE_NO,  LEVEL_0, ("---", 0),  ("", "https://librazik.tuxfamily.org/doc3/logiciels/x42-plugins/x42-k20-rms_meter") ],

  [ "x42-plugins",     "X42-Meter - K14",         "Mesureur",                   "x42-meter 2",            "x42-meters",       TEMPLATE_NO,  LEVEL_0, ("---", 0),  ("", "https://librazik.tuxfamily.org/doc3/logiciels/x42-plugins/x42-k14-rms_meter") ],

  [ "x42-plugins",     "X42-Meter - K12",         "Mesureur",                   "x42-meter 3",            "x42-meters",       TEMPLATE_NO,  LEVEL_0, ("---", 0),  ("", "https://librazik.tuxfamily.org/doc3/logiciels/x42-plugins/x42-k12-rms_meter") ],

  [ "x42-plugins",     "X42-Meter - BBC",         "Mesureur",                   "x42-meter 4",            "x42-meters",       TEMPLATE_NO,  LEVEL_0, ("---", 0), ("", "https://librazik.tuxfamily.org/doc3/logiciels/x42-plugins/x42-bbc_meter") ],

  [ "x42-plugins",     "X42-Meter - BBC M-6",     "Mesureur",                   "x42-meter 5",            "x42-meters",       TEMPLATE_NO,  LEVEL_0, ("---", 0), ("", "https://librazik.tuxfamily.org/doc3/logiciels/x42-plugins/x42-bbc_m-6") ],

  [ "x42-plugins",     "X42-Meter - DIN",         "Mesureur",                   "x42-meter 6",            "x42-meters",       TEMPLATE_NO,  LEVEL_0, ("---", 0), ("", "https://librazik.tuxfamily.org/doc3/logiciels/x42-plugins/x42-din_meter") ],

  [ "x42-plugins",     "X42-Meter - EBU",         "Mesureur",                   "x42-meter 7",            "x42-meters",       TEMPLATE_NO,  LEVEL_0, ("---", 0), ("", "https://librazik.tuxfamily.org/doc3/logiciels/x42-plugins/x42-ebu_meter") ],

  [ "x42-plugins",     "X42-Meter - Nordic",      "Mesureur",                   "x42-meter 8",            "x42-meters",       TEMPLATE_NO,  LEVEL_0, ("---", 0), ("", "https://librazik.tuxfamily.org/doc3/logiciels/x42-plugins/x42-nordic_meter") ],

  [ "x42-plugins",     "X42-Meter - VU",          "Mesureur",                   "x42-meter 9",            "x42-meters",       TEMPLATE_NO,  LEVEL_0, ("---", 0), ("", "https://librazik.tuxfamily.org/doc3/logiciels/x42-plugins/x42-vu_meter") ],

  [ "x42-plugins",     "X42-Meter - True Peak et RMS",            "Mesureur",   "x42-meter 10",           "x42-meters",       TEMPLATE_NO,  LEVEL_0, ("---", 0), ("", "https://librazik.tuxfamily.org/doc3/logiciels/x42-plugins/x42-true-peak_and_rms_meter") ],

  [ "x42-plugins",     "X42-Meter - Dynamic Range",               "Mesureur",   "x42-meter 11",           "x42-meters",       TEMPLATE_NO,  LEVEL_0, ("---", 0), ("", "https://librazik.tuxfamily.org/doc3/logiciels/x42-plugins/x42-dr14_-_dynamic_range_meter") ],

  [ "x42-plugins",     "X42-Meter - Phase Correlation ",          "Mesureur",   "x42-meter 12",           "x42-meters",       TEMPLATE_NO,  LEVEL_0, ("---", 0), ("", "https://librazik.tuxfamily.org/doc3/logiciels/x42-plugins/x42-stereo_phase-correlation_meter") ],

  [ "x42-plugins",     "X42-Meter - Goniometer",                  "Mesureur",   "x42-meter 13",           "x42-meters",       TEMPLATE_NO,  LEVEL_0, ("---", 0), ("", "https://librazik.tuxfamily.org/doc3/logiciels/x42-plugins/x42-goniometer") ],

  [ "x42-plugins",     "X42-Meter - Phase Frequency Wheel",       "Mesureur",   "x42-meter 14",           "x42-meters",       TEMPLATE_NO,  LEVEL_0, ("---", 0), ("", "https://librazik.tuxfamily.org/doc3/logiciels/x42-plugins/x42-phase-frequency_wheel") ],

  [ "x42-plugins",     "X42-Meter - 1/3 Octave Spectrum",         "Mesureur",   "x42-meter 15",           "x42-meters",       TEMPLATE_NO,  LEVEL_0, ("---", 0), ("", "https://librazik.tuxfamily.org/doc3/logiciels/x42-plugins/x42-1-3_octave_spectrum_display") ],

  [ "x42-plugins",     "X42-Meter - Frequency Scope",             "Mesureur",   "x42-meter 16",           "x42-meters",       TEMPLATE_NO,  LEVEL_0, ("---", 0), ("", "https://librazik.tuxfamily.org/doc3/logiciels/x42-plugins/x42-stereo-frequency_scope") ],

  [ "x42-plugins",     "X42-Meter - Distribution Histogram",      "Mesureur",   "x42-meter 17",           "x42-meters",       TEMPLATE_NO,  LEVEL_0, ("---", 0), ("", "https://librazik.tuxfamily.org/doc3/logiciels/x42-plugins/x42-signal_distribution_histogram") ],

  [ "x42-plugins",     "X42-Meter - Bitmeter",                    "Mesureur",   "x42-meter 18",           "x42-meters",       TEMPLATE_NO,  LEVEL_0, ("---", 0), ("", "https://librazik.tuxfamily.org/doc3/logiciels/x42-plugins/x42-bit_meter") ],

  [ "x42-plugins",     "X42-Meter - Surround Analysor",           "Mesureur",   "x42-meter 19",           "x42-meters",       TEMPLATE_NO,  LEVEL_0, ("---", 0), ("", "https://librazik.tuxfamily.org/doc3/logiciels/x42-plugins/x42-surround") ],

  [ "x42-plugins", "X42 - Mixtri", "Mixeur matriciel et un processeur de déclenchement", "x42-mixtri",    "x42-mixtri",       TEMPLATE_NO,  LEVEL_0, ("---", 0), ("", "https://librazik.tuxfamily.org/doc3/logiciels/x42-plugins/x42-mixer_n_trigger") ],

  [ "x42-plugins",     "X42 - Oscilloscope",      "Oscilloscope",               "x42-scope",              "x42-scope",        TEMPLATE_NO,  LEVEL_0, ("---", 0), ("", "https://librazik.tuxfamily.org/doc3/logiciels/x42-plugins/x42-simple_scope") ],

  [ "x42-plugins",     "X42 - Tuna",              "Accordeur d'instrument",     "x42-tuna",               "x42-tuna",         TEMPLATE_NO,  LEVEL_0, ("---", 0), ("", "https://librazik.tuxfamily.org/doc3/logiciels/x42-plugins/x42-instrument_tuner") ],

  [ "x42-plugins",     "X42 - Tuna - spectral",  "Accordeur d'instrument - spectral", "x42-tuna 1",       "x42-tuna",         TEMPLATE_NO,  LEVEL_0, ("---", 0), ("", "https://librazik.tuxfamily.org/doc3/logiciels/x42-plugins/x42-instrument_tuner") ],

  [ "xjadeo",          "XJadeo",   "Lecteur vidéo synchronisable avec le transport JACK",   "qjadeo",    "qjadeo",            TEMPLATE_NO,  LEVEL_0, ("---", 1), ("", "https://librazik.tuxfamily.org/doc3/logiciels/xjadeo") ],

  [ "zita-bls1",       "Zita-bls1",    "Convertisseur signaux binauraux -> stéréo",   "zita-bls1",        "zita-bls1",        TEMPLATE_NO,  LEVEL_0, ("---", 0), ("", "https://librazik.tuxfamily.org/doc3/logiciels/zita-bls1") ],

  [ "zita-mu1",        "Zita-mu1",        "Organisateur de monitoring stéréo",        "zita-mu1",         "zita-mu1",         TEMPLATE_NO,  LEVEL_0, ("---", 0), ("", "https://librazik.tuxfamily.org/doc3/logiciels/zita-mu1") ],

]

iTool_Package, iTool_AppName, iTool_Type, iTool_Binary, iTool_Icon, iTool_Template, iTool_Level, iTool_Features, iTool_Docs = range(0, len(list_Tool[0]))

if USING_KXSTUDIO:
    # Non-Mixer
    list_Tool[10][iDAW_Level] = LEVEL_1
